@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -23,7 +23,7 @@ class CodeClassField;
  * associations) in the code document for any given code classfield. This is a
  * special CodeBlockWithComments which is "sync'd" to the parent CodeClassField.
  * Note: keep the inheritance sequence: QObject needs to be first in inheritance list.
- * Basicially a class to allow for synchronization of the contents based on the
+ * Basically a class to allow for synchronization of the contents based on the
  * values of the parentClassField's parentObject.
  */
 class CodeClassFieldDeclarationBlock : public OwnedCodeBlock, public CodeBlockWithComments
@@ -43,15 +43,15 @@ public:
 
     virtual void updateContent() = 0;
 
-    virtual void saveToXMI(QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
 
-    virtual void loadFromXMI(QDomElement & root);
+    virtual void loadFromXMI1(QDomElement & root);
 
 protected:
 
     virtual void release();
 
-    virtual void setAttributesOnNode(QDomDocument & doc, QDomElement & blockElement);
+    virtual void setAttributesOnNode(QXmlStreamWriter& writer);
 
     virtual void setAttributesFromNode(QDomElement & element);
 
