@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -22,6 +22,9 @@
 #include "uml.h"
 #include "umldoc.h"
 
+// qt/kde includes
+#include <QXmlStreamWriter>
+
 /**
  * Constructor
  * @param parent   parent code document
@@ -143,7 +146,7 @@ CodeGenObjectWithTextBlocks * CodeGenObjectWithTextBlocks::findParentObjectForTa
 {
     // what??!? no tag, then CANT be here
     if (tag.isEmpty())
-        return (CodeGenObjectWithTextBlocks*) NULL;
+        return (CodeGenObjectWithTextBlocks*) 0;
 
     if (!findTextBlockByTag(tag)) {
         // may be hiding in child hierarchical codeblock
@@ -162,7 +165,7 @@ CodeGenObjectWithTextBlocks * CodeGenObjectWithTextBlocks::findParentObjectForTa
 
     // shouldn't happen unless the textblock doesn't exist in this object
     // or its children at all
-    return (CodeGenObjectWithTextBlocks*) NULL;
+    return (CodeGenObjectWithTextBlocks*) 0;
 }
 
 /**
@@ -187,7 +190,7 @@ HierarchicalCodeBlock * CodeGenObjectWithTextBlocks::getHierarchicalCodeBlock (c
             codeBlock->getComment()->setWriteOutText(false);
         if (!addTextBlock(codeBlock)) {
             delete codeBlock;
-            return (HierarchicalCodeBlock*) NULL;
+            return (HierarchicalCodeBlock*) 0;
         }
     }
 
@@ -219,7 +222,7 @@ CodeBlockWithComments * CodeGenObjectWithTextBlocks::getCodeBlockWithComments (c
             codeBlock->getComment()->setWriteOutText(false);
         if (!addTextBlock(codeBlock)) {
             delete codeBlock;
-            return (CodeBlockWithComments*) NULL;
+            return (CodeBlockWithComments*) 0;
         }
     }
     codeBlock->setOverallIndentationLevel (indentLevel);
@@ -324,50 +327,9 @@ void CodeGenObjectWithTextBlocks::resetTextBlocks()
 {
     /**************  @todo I had to deactivate this code:
     TextBlock *tb;
-    for (TextBlockListIt it(m_textblockVector); (tb = it.current()) != NULL; ++it)
+    for (TextBlockListIt it(m_textblockVector); (tb = it.current()) != 0; ++it)
         delete tb;
-     **************  else the following crash happens on loading an XMI file:
-     Invalid read of size 4
-        at 0x8134BAA: QString::QString(QString const&) (qstring.h:650)
-        by 0x8331EE5: TextBlock::getTag() const (textblock.cpp:103)
-        by 0x82C4634: ClassifierCodeDocument::findCodeClassFieldTextBlockByTag(QString const&) (classifiercodedocument.cpp:730)
-        by 0x82F3940: HierarchicalCodeBlock::findCodeClassFieldTextBlockByTag(QString const&) (hierarchicalcodeblock.cpp:366)
-        by 0x82D71DC: CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode(QDomElement&) (codegenobjectwithtextblocks.cpp:422)
-        by 0x82D6DFF: CodeGenObjectWithTextBlocks::setAttributesFromNode(QDomElement&) (codegenobjectwithtextblocks.cpp:373)
-        by 0x82F3412: HierarchicalCodeBlock::setAttributesFromNode(QDomElement&) (hierarchicalcodeblock.cpp:290)
-        by 0x82F3248: HierarchicalCodeBlock::loadFromXMI(QDomElement&) (hierarchicalcodeblock.cpp:269)
-        by 0x82D760F: CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode(QDomElement&) (codegenobjectwithtextblocks.cpp:453)
-        by 0x82D6DFF: CodeGenObjectWithTextBlocks::setAttributesFromNode(QDomElement&) (codegenobjectwithtextblocks.cpp:373)
-        by 0x82CFB9C: CodeDocument::setAttributesFromNode(QDomElement&) (codedocument.cpp:414)
-        by 0x82C3CAE: ClassifierCodeDocument::setAttributesFromNode(QDomElement&) (classifiercodedocument.cpp:595)
-        by 0x82C4388: ClassifierCodeDocument::loadFromXMI(QDomElement&) (classifiercodedocument.cpp:687)
-        by 0x82D372E: CodeGenerator::loadFromXMI(QDomElement&) (codegenerator.cpp:205)
-        by 0x8356381: UMLDoc::loadExtensionsFromXMI(QDomNode&) (umldoc.cpp:1774)
-        by 0x8353F16: UMLDoc::loadFromXMI(QIODevice&, short) (umldoc.cpp:1480)
-        by 0x834DBB6: UMLDoc::openDocument(KUrl const&, char const*) (umldoc.cpp:475)
-        by 0x833F0DE: UMLApp::openDocumentFile(KUrl const&) (uml.cpp:642)
-        by 0x83098D9: initDocument(KCmdLineArgs*) (main.cpp:125)
-        by 0x830974D: main (main.cpp:101)
-      Address 0x66539DC is 12 bytes inside a block of size 68 free'd
-        at 0x401D567: operator delete(void*) (vg_replace_malloc.c:244)
-        by 0x8204CA2: CPPSourceCodeAccessorMethod::~CPPSourceCodeAccessorMethod() (cppsourcecodeaccessormethod.cpp:51)
-        by 0x82D6C6D: CodeGenObjectWithTextBlocks::resetTextBlocks() (codegenobjectwithtextblocks.cpp:333)
-        by 0x82D6001: CodeGenObjectWithTextBlocks::~CodeGenObjectWithTextBlocks() (codegenobjectwithtextblocks.cpp:42)
-        by 0x82F272A: HierarchicalCodeBlock::~HierarchicalCodeBlock() (hierarchicalcodeblock.cpp:41)
-        by 0x82D6C6D: CodeGenObjectWithTextBlocks::resetTextBlocks() (codegenobjectwithtextblocks.cpp:333)
-        by 0x82CF294: CodeDocument::resetTextBlocks() (codedocument.cpp:330)
-        by 0x82026EC: CPPSourceCodeDocument::resetTextBlocks() (cppsourcecodedocument.cpp:111)
-        by 0x82D6DE7: CodeGenObjectWithTextBlocks::setAttributesFromNode(QDomElement&) (codegenobjectwithtextblocks.cpp:370)
-        by 0x82CFB9C: CodeDocument::setAttributesFromNode(QDomElement&) (codedocument.cpp:414)
-        by 0x82C3CAE: ClassifierCodeDocument::setAttributesFromNode(QDomElement&) (classifiercodedocument.cpp:595)
-        by 0x82C4388: ClassifierCodeDocument::loadFromXMI(QDomElement&) (classifiercodedocument.cpp:687)
-        by 0x82D372E: CodeGenerator::loadFromXMI(QDomElement&) (codegenerator.cpp:205)
-        by 0x8356381: UMLDoc::loadExtensionsFromXMI(QDomNode&) (umldoc.cpp:1774)
-        by 0x8353F16: UMLDoc::loadFromXMI(QIODevice&, short) (umldoc.cpp:1480)
-        by 0x834DBB6: UMLDoc::openDocument(KUrl const&, char const*) (umldoc.cpp:475)
-        by 0x833F0DE: UMLApp::openDocumentFile(KUrl const&) (uml.cpp:642)
-        by 0x83098D9: initDocument(KCmdLineArgs*) (main.cpp:125)
-        by 0x830974D: main (main.cpp:101)
+     **************  else crash happens on loading an XMI file
      *************/
 
     m_textBlockTagMap.clear();
@@ -393,17 +355,17 @@ void CodeGenObjectWithTextBlocks::setAttributesFromObject (CodeGenObjectWithText
  * Set attributes of the node that represents this class
  * in the XMI document.
  */
-void CodeGenObjectWithTextBlocks::setAttributesOnNode (QDomDocument & doc, QDomElement & root)
+void CodeGenObjectWithTextBlocks::setAttributesOnNode (QXmlStreamWriter& writer)
 {
     // set a section to hold document content
-    QDomElement tblockElement = doc.createElement(QLatin1String("textblocks"));
+    writer.writeStartElement(QLatin1String("textblocks"));
 
     // only concrete calls to textblocks are saved
     TextBlockList * tbList = getTextBlockList();
     foreach (TextBlock* block, *tbList) {
-        block->saveToXMI(doc, tblockElement);
+        block->saveToXMI1(writer);
     }
-    root.appendChild(tblockElement);
+    writer.writeEndElement();
 }
 
 /**
@@ -453,7 +415,7 @@ void CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode (QDomElement & roo
 
             if (name == QLatin1String("codecomment")) {
                 CodeComment * block = CodeGenFactory::newCodeComment(m_pCodeDoc);
-                block->loadFromXMI(element);
+                block->loadFromXMI1(element);
                 if (!addTextBlock(block)) {
                     uError() << "unable to add codeComment to :" << this;
                     delete block;
@@ -474,7 +436,7 @@ void CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode (QDomElement & roo
 
             } else if (name == QLatin1String("codeblock")) {
                 CodeBlock * block = newCodeBlock();
-                block->loadFromXMI(element);
+                block->loadFromXMI1(element);
                 if (!addTextBlock(block)) {
                     uError() << "unable to add codeBlock to :" << this;
                     delete block;
@@ -483,7 +445,7 @@ void CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode (QDomElement & roo
 
             } else if (name == QLatin1String("codeblockwithcomments")) {
                 CodeBlockWithComments * block = newCodeBlockWithComments();
-                block->loadFromXMI(element);
+                block->loadFromXMI1(element);
                 if (!addTextBlock(block)) {
                     uError() << "unable to add codeBlockwithcomments to:" << this;
                     delete block;
@@ -495,7 +457,7 @@ void CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode (QDomElement & roo
 
             } else if (name == QLatin1String("hierarchicalcodeblock")) {
                 HierarchicalCodeBlock * block = new HierarchicalCodeBlock(m_pCodeDoc);
-                block->loadFromXMI(element);
+                block->loadFromXMI1(element);
                 if (!addTextBlock(block)) {
                     uError() << "unable to add hierarchicalcodeBlock to:" << this;
                     delete block;
@@ -506,10 +468,10 @@ void CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode (QDomElement & roo
                 // find the code operation by id
                 QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
                 UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                UMLOperation * op = obj->asUMLOperation();
                 if (op) {
                     CodeOperation * block = CodeGenFactory::newCodeOperation(dynamic_cast<ClassifierCodeDocument*>(m_pCodeDoc), op);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (addTextBlock(block))
                         loadCheckForChildrenOK = true;
                     else {
@@ -519,7 +481,7 @@ void CodeGenObjectWithTextBlocks::loadChildTextBlocksFromNode (QDomElement & roo
                 } else
                     uError() << "unable to create codeoperation for obj id:" << id;
             } else
-                uWarning() << "Got strange tag in text block stack: name=" << name << ", ignorning";
+                uWarning() << "Got strange tag in text block stack: name=" << name << ", ignoring";
 
             node = element.nextSibling();
             element = node.toElement();
