@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -23,6 +23,9 @@
 #include "uml.h"
 #include "codegenfactory.h"
 
+// qt/kde includes
+#include <QXmlStreamWriter>
+
 /**
  * Constructor.
  */
@@ -147,7 +150,7 @@ UMLObject * CodeParameter::getParentObject()
 // this is kind of broken for UMLRoles.
 QString CodeParameter::ID()
 {
-    UMLRole * role = dynamic_cast<UMLRole*>(m_parentObject);
+    UMLRole * role = m_parentObject->asUMLRole();
     if (role)
     {
         // cant use Role "ID" as that is used to distinquish if its
@@ -163,26 +166,26 @@ QString CodeParameter::ID()
  * Set attributes of the node that represents this class
  * in the XMI document.
  */
-void CodeParameter::setAttributesOnNode(QDomDocument & doc, QDomElement & blockElement)
+void CodeParameter::setAttributesOnNode(QXmlStreamWriter& writer)
 {
     // set local attributes
-    blockElement.setAttribute(QLatin1String("parent_id"), ID());
+    writer.writeAttribute(QLatin1String("parent_id"), ID());
 
     // setting ID's takes special treatment
     // as UMLRoles arent properly stored in the XMI right now.
     // (change would break the XMI format..save for big version change)
-    UMLRole * role = dynamic_cast<UMLRole*>(m_parentObject);
+    UMLRole * role = m_parentObject->asUMLRole();
     if (role)
-        blockElement.setAttribute(QLatin1String("role_id"), role->role());
+        writer.writeAttribute(QLatin1String("role_id"), QString::number(role->role()));
     else
-        blockElement.setAttribute(QLatin1String("role_id"), QLatin1String("-1"));
+        writer.writeAttribute(QLatin1String("role_id"), QLatin1String("-1"));
 
-    blockElement.setAttribute(QLatin1String("initialValue"), getInitialValue());
+    writer.writeAttribute(QLatin1String("initialValue"), getInitialValue());
 
     // a comment which we will store in its own separate child node block
-    QDomElement commElement = doc.createElement(QLatin1String("header"));
-    getComment()->saveToXMI(doc, commElement); // comment
-    blockElement.appendChild(commElement);
+    writer.writeStartElement(QLatin1String("header"));
+    getComment()->saveToXMI1(writer); // comment
+    writer.writeEndElement();
 }
 
 /**
@@ -212,7 +215,7 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
         // might ripple throughout the code and cause problems. Thus, since the
         // change appears to be needed for only this part, I'll do this crappy
         // change instead. -b.t.
-        UMLAssociation * assoc = dynamic_cast<UMLAssociation*>(obj);
+        UMLAssociation * assoc = obj->asUMLAssociation();
         if (assoc) {
             // In this case we init with indicated role child obj.
             UMLRole * role = 0;
@@ -250,7 +253,7 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
         if (tag == QLatin1String("header")) {
             QDomNode cnode = element.firstChild();
             QDomElement celem = cnode.toElement();
-            getComment()->loadFromXMI(celem);
+            getComment()->loadFromXMI1(celem);
             gotComment = true;
             break;
         }
@@ -259,7 +262,7 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
     }
 
     if (!gotComment)
-        uWarning()<<" loadFromXMI : Warning: unable to initialize CodeComment in codeparam:"<<this;
+        uWarning()<<" loadFromXMI1 : Warning: unable to initialize CodeComment in codeparam:"<<this;
 }
 
 /**
@@ -286,4 +289,3 @@ void CodeParameter::initFields(ClassifierCodeDocument * doc, UMLObject * obj)
     connect(m_parentObject, SIGNAL(modified()), this, SLOT(syncToParent()));
 }
 
-#include "codeparameter.moc"
