@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -33,12 +33,12 @@ CPPCodeDocumentation::~CPPCodeDocumentation()
 /**
  * Save the XMI representation of this object
  */
-void CPPCodeDocumentation::saveToXMI(QDomDocument & doc, QDomElement & root)
+void CPPCodeDocumentation::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement blockElement = doc.createElement(QLatin1String("cppcodedocumentation"));
-    setAttributesOnNode(doc, blockElement); // as we added no additional fields to this class we may
+    writer.writeStartElement(QLatin1String("cppcodedocumentation"));
+    setAttributesOnNode(writer); // as we added no additional fields to this class we may
     // just use parent TextBlock method
-    root.appendChild(blockElement);
+    writer.writeEndElement();
 }
 
 /**
@@ -103,7 +103,7 @@ int CPPCodeDocumentation::lastEditableLine()
 }
 
 /** UnFormat a long text string. Typically, this means removing
- *  the indentaion (linePrefix) and/or newline chars from each line.
+ *  the indentation (linePrefix) and/or newline chars from each line.
  */
 QString CPPCodeDocumentation::unformatText(const QString & text, const QString & indent)
 {
