@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -102,7 +102,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
 
                 if(name == QLatin1String("codecomment")) {
                     CodeComment * block = new CPPCodeDocumentation(this);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if(!addTextBlock(block))
                     {
                         uError()<<"Unable to add codeComment to :"<<this;
@@ -125,7 +125,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                     } else
                         if(name == QLatin1String("codeblock")) {
                             CodeBlock * block = newCodeBlock();
-                            block->loadFromXMI(element);
+                            block->loadFromXMI1(element);
                             if(!addTextBlock(block))
                             {
                                 uError()<<"Unable to add codeBlock to :"<<this;
@@ -135,7 +135,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                         } else
                             if(name == QLatin1String("codeblockwithcomments")) {
                                 CodeBlockWithComments * block = newCodeBlockWithComments();
-                                block->loadFromXMI(element);
+                                block->loadFromXMI1(element);
                                 if(!addTextBlock(block))
                                 {
                                     uError()<<"Unable to add codeBlockwithcomments to:"<<this;
@@ -148,7 +148,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                                 } else
                                     if(name == QLatin1String("hierarchicalcodeblock")) {
                                         HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                                        block->loadFromXMI(element);
+                                        block->loadFromXMI1(element);
                                         if(!addTextBlock(block))
                                         {
                                             uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
@@ -160,12 +160,12 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                                             // find the code operation by id
                                             QString id = element.attribute(QLatin1String("parent_id"),QLatin1String("-1"));
                                             UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                                            UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                                            UMLOperation * op = obj->asUMLOperation();
                                             if(op) {
                                                 CodeOperation * block = new CPPHeaderCodeOperation(this, op);
                                                 block->updateMethodDeclaration();
                                                 block->updateContent();
-                                                block->loadFromXMI(element);
+                                                block->loadFromXMI1(element);
                                                 if(addTextBlock(block))
                                                     loadCheckForChildrenOK= true;
                                                 else
@@ -180,7 +180,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                                             if(name == QLatin1String("cppheaderclassdeclarationblock"))
                                             {
                                                 CPPHeaderClassDeclarationBlock * block = getClassDecl();
-                                                block->loadFromXMI(element);
+                                                block->loadFromXMI1(element);
                                                 // normally this would be populated by the following syncToparent
                                                 // call, but we cant wait for it, so lets just do it now.
                                                 m_namespaceBlock = getHierarchicalCodeBlock(QLatin1String("namespace"), QLatin1String("Namespace"), 0);
@@ -196,7 +196,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                                             }
                 // only needed for extreme debugging conditions (E.g. making new codeclassdocument loader)
                 //else
-                //uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning";
+                //uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignoring";
 
                 node = element.nextSibling();
                 element = node.toElement();
@@ -269,14 +269,14 @@ void CPPHeaderCodeDocument::resetTextBlocks()
 
 /**
  * Add a code operation to this cpp classifier code document.
- * In the vannilla version, we just tack all operations on the end
+ * In the vanilla version, we just tack all operations on the end
  * of the document.
  * @param op   the code operation
  * @return bool which is true IF the code operation was added successfully
  */
 bool CPPHeaderCodeDocument::addCodeOperation(CodeOperation* op)
 {
-    if (op == NULL) {
+    if (op == 0) {
         uDebug() << "CodeOperation is null!";
         return false;;
     }
@@ -286,26 +286,26 @@ bool CPPHeaderCodeDocument::addCodeOperation(CodeOperation* op)
         switch (scope) {
         default:
         case Uml::Visibility::Public:
-            return (m_pubOperationsBlock == NULL ? false : m_pubOperationsBlock->addTextBlock(op));
+            return (m_pubOperationsBlock == 0 ? false : m_pubOperationsBlock->addTextBlock(op));
             break;
         case Uml::Visibility::Protected:
-            return (m_protOperationsBlock == NULL ? false : m_protOperationsBlock->addTextBlock(op));
+            return (m_protOperationsBlock == 0 ? false : m_protOperationsBlock->addTextBlock(op));
             break;
         case Uml::Visibility::Private:
-            return (m_privOperationsBlock == NULL ? false : m_privOperationsBlock->addTextBlock(op));
+            return (m_privOperationsBlock == 0 ? false : m_privOperationsBlock->addTextBlock(op));
             break;
         }
     } else {
         switch (scope) {
         default:
         case Uml::Visibility::Public:
-            return (m_pubConstructorBlock == NULL ? false : m_pubConstructorBlock->addTextBlock(op));
+            return (m_pubConstructorBlock == 0 ? false : m_pubConstructorBlock->addTextBlock(op));
             break;
         case Uml::Visibility::Protected:
-            return (m_protConstructorBlock == NULL ? false : m_protConstructorBlock->addTextBlock(op));
+            return (m_protConstructorBlock == 0 ? false : m_protConstructorBlock->addTextBlock(op));
             break;
         case Uml::Visibility::Private:
-            return (m_privConstructorBlock == NULL ? false : m_privConstructorBlock->addTextBlock(op));
+            return (m_privConstructorBlock == 0 ? false : m_privConstructorBlock->addTextBlock(op));
             break;
         }
     }
@@ -316,13 +316,13 @@ bool CPPHeaderCodeDocument::addCodeOperation(CodeOperation* op)
  * @return      bool    status of save
  */
 /*
-void CPPHeaderCodeDocument::saveToXMI (QDomDocument & doc, QDomElement & root)
+void CPPHeaderCodeDocument::saveToXMI1(QXmlStreamWriter& writer)
 {
-        QDomElement docElement = doc.createElement(QString());
+        writer.writeEmptyStartElement();
 
-        setAttributesOnNode(doc, docElement);
+        setAttributesOnNode(writer);
 
-        root.appendChild(docElement);
+        writer.writeEndElement();
 }
 */
 
@@ -330,14 +330,14 @@ void CPPHeaderCodeDocument::saveToXMI (QDomDocument & doc, QDomElement & root)
 // based on the parent classifier object.
 // For any situation in which this is called, we are either building the code
 // document up, or replacing/regenerating the existing auto-generated parts. As
-// such, we will want to insert everything we resonablely will want
+// such, we will want to insert everything we reasonably will want
 // during creation. We can set various parts of the document (esp. the
 // comments) to appear or not, as needed.
 void CPPHeaderCodeDocument::updateContent()
 {
     // Gather info on the various fields and parent objects of this class...
     UMLClassifier * c = getParentClassifier();
-    Q_ASSERT(c != NULL);
+    Q_ASSERT(c != 0);
     CodeGenPolicyExt *pe = UMLApp::app()->policyExt();
     CPPCodeGenerationPolicy * policy = dynamic_cast<CPPCodeGenerationPolicy*>(pe);
 
@@ -419,7 +419,7 @@ void CPPHeaderCodeDocument::updateContent()
 
     CodeGenerator::findObjectsRelated(c, includes);
     foreach(UMLPackage* con, includes) {
-        if (con->baseType() != UMLObject::ot_Datatype && !packageMap.contains(con)) {
+        if (!con->isUMLDatatype() && !packageMap.contains(con)) {
             packageMap.insert(con, con->package());
             if(con != getParentClassifier())
                 includeStatement.append(QLatin1String("#include \"") + CodeGenerator::cleanName(con->name().toLower()) + QLatin1String(".h\"") + endLine);
@@ -481,7 +481,7 @@ void CPPHeaderCodeDocument::updateContent()
     if (!isInterface) {
         QString enumStatement;
         QString indent = UMLApp::app()->commonPolicy()->getIndentation();
-        UMLEnum* e = dynamic_cast<UMLEnum*>(c);
+        UMLEnum* e = c->asUMLEnum();
         if (e) {
             enumStatement.append(indent + QLatin1String("enum ") + cppClassName + QLatin1String(" {") + endLine);
 
@@ -637,7 +637,7 @@ void CPPHeaderCodeDocument::updateContent()
 
     // public
     m_pubConstructorBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
-    // special condiions for showing comment: only when autogenerateding empty constructors
+    // special conditions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * pubConstComment = m_pubConstructorBlock->getComment();
     if (!forcedoc && (isInterface || !pol->getAutoGenerateConstructors()))
@@ -647,7 +647,7 @@ void CPPHeaderCodeDocument::updateContent()
 
     // protected
     m_protConstructorBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
-    // special condiions for showing comment: only when autogenerateding empty constructors
+    // special conditions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * protConstComment = m_protConstructorBlock->getComment();
     if (!forcedoc && (isInterface || !pol->getAutoGenerateConstructors()))
@@ -657,7 +657,7 @@ void CPPHeaderCodeDocument::updateContent()
 
     // private
     m_privConstructorBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
-    // special condiions for showing comment: only when autogenerateding empty constructors
+    // special conditions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * privConstComment = m_privConstructorBlock->getComment();
     if (!forcedoc && (isInterface || !pol->getAutoGenerateConstructors()))
