@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
+ *   copyright (C) 2008-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -13,7 +13,7 @@
 #define DCODEGENERATOR_H
 
 #include "codeviewerstate.h"
-#include "codegenerator.h"
+#include "advancedcodegenerator.h"
 #include "codeblockwithcomments.h"
 #include "dclassifiercodedocument.h"
 #include "dcodegenerationpolicy.h"
@@ -23,7 +23,7 @@
 
 class CodeViewerDialog;
 
-class DCodeGenerator : public CodeGenerator
+class DCodeGenerator : public AdvancedCodeGenerator
 {
     Q_OBJECT
 public:
