@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -30,17 +30,17 @@ JavaClassDeclarationBlock::~JavaClassDeclarationBlock ()
 /**
  * Save the XMI representation of this object
  */
-void JavaClassDeclarationBlock::saveToXMI (QDomDocument & doc, QDomElement & root)
+void JavaClassDeclarationBlock::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement blockElement = doc.createElement(QLatin1String("javaclassdeclarationblock"));
-    setAttributesOnNode(doc, blockElement);
-    root.appendChild(blockElement);
+    writer.writeStartElement(QLatin1String("javaclassdeclarationblock"));
+    setAttributesOnNode(writer);
+    writer.writeEndElement();
 }
 
 /**
  * load params from the appropriate XMI element node.
  */
-void JavaClassDeclarationBlock::loadFromXMI (QDomElement & root)
+void JavaClassDeclarationBlock::loadFromXMI1 (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -51,6 +51,7 @@ void JavaClassDeclarationBlock::loadFromXMI (QDomElement & root)
 void JavaClassDeclarationBlock::updateContent ()
 {
     JavaClassifierCodeDocument *parentDoc = dynamic_cast<JavaClassifierCodeDocument*>(getParentDocument());
+    Q_ASSERT(parentDoc);
     UMLClassifier *c = parentDoc->getParentClassifier();
     CodeGenerationPolicy *commonPolicy = UMLApp::app()->commonPolicy();
     QString endLine = commonPolicy->getNewLineEndingChars();
@@ -141,4 +142,3 @@ void JavaClassDeclarationBlock::init (JavaClassifierCodeDocument *parentDoc, con
 }
 
 
-#include "javaclassdeclarationblock.moc"
