@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -22,6 +22,9 @@
 #include "uml.h"
 #include "textblock.h"
 
+// qt includes
+#include <QXmlStreamWriter>
+
 /**
  * Constructor
  */
@@ -78,23 +81,23 @@ void OwnedCodeBlock::setAttributesFromObject (TextBlock * obj)
     }
 }
 
-void OwnedCodeBlock::setAttributesOnNode(QDomDocument& /*doc*/, QDomElement& elem)
+void OwnedCodeBlock::setAttributesOnNode(QXmlStreamWriter& writer)
 {
     // set local class attributes
     // setting ID's takes special treatment
     // as UMLRoles arent properly stored in the XMI right now.
     // (change would break the XMI format..save for big version change)
-    UMLRole * role = dynamic_cast<UMLRole*>(m_parentObject);
+    UMLRole * role = m_parentObject->asUMLRole();
     if (role) {
-        elem.setAttribute(QLatin1String("parent_id"), Uml::ID::toString(role->parentAssociation()->id()));
+        writer.writeAttribute(QLatin1String("parent_id"), Uml::ID::toString(role->parentAssociation()->id()));
         // CAUTION: role_id here is numerically inverted wrt Uml::Role_Type,
         //          i.e. role A is 1 and role B is 0.
         //          I'll resist the temptation to change this -
         //          in order to maintain backward compatibility.
-        elem.setAttribute(QLatin1String("role_id"), (role->role() == Uml::RoleType::A));
+        writer.writeAttribute(QLatin1String("role_id"), QString::number((role->role() == Uml::RoleType::A)));
     }
     else {
-        elem.setAttribute(QLatin1String("parent_id"), Uml::ID::toString(m_parentObject->id()));
+        writer.writeAttribute(QLatin1String("parent_id"), Uml::ID::toString(m_parentObject->id()));
         //elem.setAttribute(QLatin1String("role_id"),QLatin1String("-1"));
     }
 }
@@ -125,7 +128,7 @@ void OwnedCodeBlock::setAttributesFromNode (QDomElement & elem)
         // might ripple throughout the code and cause problems. Thus, since the
         // change appears to be needed for only this part, I'll do this crappy
         // change instead. -b.t.
-        UMLAssociation * assoc = dynamic_cast<UMLAssociation*>(obj);
+        UMLAssociation * assoc = obj->asUMLAssociation();
         if (assoc) {
             // In this case we init with indicated role child obj.
             UMLRole * role = 0;
