@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2002                                                    *
  *   Luis De la Parra  <luis@delaparra.org>                                *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 #ifndef CODEGENSTATUSPAGE_H
@@ -17,6 +17,7 @@
 #include "basictypes.h"
 #include "classifier.h"
 #include "codegenerationpolicy.h"
+#include "codegenerator.h"
 
 // kde includes
 #include <kled.h>
@@ -42,10 +43,11 @@ public:
 
 private:
     bool m_generationDone;
-      
+
 protected slots:
     void generateCode();
     void classGenerated(UMLClassifier* concept, bool generated);
+    void classGenerated(UMLClassifier* classifier, CodeGenerator::GenerationState state);
     void populateStatusList();
     void showFileGenerated(const QString& filename);
     void loggerClear();
@@ -65,10 +67,10 @@ class LedStatus : public QWidget
             layout->addWidget(m_led);
             layout->addItem(new QSpacerItem(20, 20));
             setLayout(layout);
-        };
-        ~LedStatus() {};
-        void setColor(const QColor& color) { m_led->setColor(color); };
-        void setOn(bool isOn) { isOn ? m_led->setState(KLed::On) : m_led->setState(KLed::Off); };
+        }
+        ~LedStatus() {}
+        void setColor(const QColor& color) { m_led->setColor(color); }
+        void setOn(bool isOn) { isOn ? m_led->setState(KLed::On) : m_led->setState(KLed::Off); }
     private:
         KLed *m_led;
 };
