@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -93,10 +93,18 @@ QString JavaImport::joinTypename(const QString& typeName)
  */
 void JavaImport::fillSource(const QString& word)
 {
+    QString w(word);
+    /* In Java, method varargs are represented by three dots following the
+       type name.  For portability to other C family languages, we replace
+       the "..." by "[]".
+     */
+    if (w.contains(QLatin1String("..."))) {
+        w.replace(QLatin1String("..."), QLatin1String("[]"));
+    }
     QString lexeme;
-    const uint len = word.length();
+    const uint len = w.length();
     for (uint i = 0; i < len; ++i) {
-        const QChar& c = word[i];
+        const QChar& c = w[i];
         if (c.isLetterOrNumber() || c == QLatin1Char('_') || c == QLatin1Char('.')) {
             lexeme += c;
         } else {
@@ -197,7 +205,7 @@ UMLObject* JavaImport::resolveClass (const QString& className)
     QStringList package = m_currentPackage.split(QLatin1Char('.'));
     int dirsInPackageCount = package.size();
 
-    // in case the path does not fit into the package hierachy 
+    // in case the path does not fit into the package hierarchy 
     // we cannot check the imports 
     if (dirsInPackageCount >= file.size())
         return 0; 
@@ -343,19 +351,19 @@ bool JavaImport::parseStmt()
             ns->setDoc(m_comment);
             m_klass = ns->asUMLClassifier();
             m_klass->setUMLPackage(currentScope());
-            currentScope()->containedObjects().append(m_klass);
+            currentScope()->addObject(m_klass, false);  // false => non interactively
         }
         pushScope(m_klass);
         m_klass->setStatic(m_isStatic);
         m_klass->setVisibilityCmd(m_currentAccess);
         // The UMLObject found by createUMLObject might originally have been created as a
-        // placeholder with a type of class but if is really an interface, then we need to
+        // placeholder with a type of class but if is really an interface then we need to
         // change it.
         m_klass->setBaseType(ot);
         // TODO: UMLClassifier::setBaseType() resets abstract flag
         m_klass->setAbstract(m_isAbstract);
         m_isAbstract = m_isStatic = false;
-        // if no modifier is specified in an interface, then it means public
+        // if no modifier is specified in an interface then it means public
         if (m_klass->isInterface()) {
             m_defaultCurrentAccess =  Uml::Visibility::Public;
         }
@@ -589,7 +597,7 @@ bool JavaImport::parseStmt()
                 break;
             m_srcIndex++;
         }
-        if (!typeName.isEmpty()) {
+        if (!typeName.isEmpty() && typeName != QLatin1String("void")) {
             // before adding the method, try resolving the return type
             UMLObject *obj = resolveClass(typeName);
             if (obj) {
