@@ -62,6 +62,104 @@ KLineEdit* makeLabeledEditField(QGridLayout* layout,    int row,
     return editField;
 }
 
+/**
+ * Make labeled edit fields for stereotype tags.
+ * The label/line-edit pairs are arranged horizontally on the same row.
+ * The label texts are taken from the AttributeDefs of the object's
+ * UMLStereotype.
+ */
+void makeTagEditFields(UMLObject *o, QGridLayout *genLayout,
+                       QLabel    *pTagLabel   [N_STEREOATTRS],
+                       KLineEdit *pTagLineEdit[N_STEREOATTRS],
+                       int row /* = 1 */)
+{
+    UMLStereotype *stereo = o->umlStereotype();
+    if (stereo == 0)
+        return;
+    const UMLStereotype::AttributeDefs& attrDefs = stereo->getAttributeDefs();
+    const QStringList& tags = o->tags();
+    for (int i = 0; i < attrDefs.size() && i < N_STEREOATTRS; i++) {
+        const UMLStereotype::AttributeDef& adef = attrDefs[i];
+        QString tagInitVal;
+        if (i < tags.size())
+            tagInitVal = tags.at(i);
+        if (tagInitVal.isEmpty())
+            tagInitVal = adef.defaultVal;
+        Dialog_Utils::makeLabeledEditField(genLayout, row,
+                                           pTagLabel[i], adef.name,
+                                           pTagLineEdit[i], tagInitVal, 2 + (i * 2));
+    }
+}
+
+/**
+ * Remake labeled edit fields for stereotype tags.
+ * "Remake" means that the existing label/line-edit pairs are deleted
+ * and new ones are created afresh.
+ * This is useful when the object's stereotype has changed.
+ * The label/line-edit pairs are arranged horizontally on the same row.
+ * The label texts are taken from the AttributeDefs of the object's
+ * UMLStereotype.
+ */
+void remakeTagEditFields(const QString &stereoText,
+                         UMLObject * o, QGridLayout * genLayout,
+                         QLabel    * pTagLabel[N_STEREOATTRS],
+                         KLineEdit * pTagLineEdit[N_STEREOATTRS],
+                         int row /* = 1 */)
+{
+    // Remove existing tag input fields
+    for (int i = N_STEREOATTRS - 1; i >= 0; --i) {
+        if (pTagLabel[i]) {
+            delete pTagLabel [i];
+            delete pTagLineEdit[i];
+            pTagLabel [i] = 0;
+            pTagLineEdit[i] = 0;
+        }
+    }
+    UMLStereotype *stereo = 0;
+    foreach (UMLStereotype *st, UMLApp::app()->document()->stereotypes()) {
+        if (st->name() == stereoText) {
+            stereo = st;
+            break;
+        }
+    }
+    if (stereo == 0)
+        return;
+    const UMLStereotype::AttributeDefs& attrDefs = stereo->getAttributeDefs();
+    for (int i = 0; i < attrDefs.size() && i < N_STEREOATTRS; i++) {
+        const UMLStereotype::AttributeDef& adef = attrDefs[i];
+        QString tagInitVal = adef.defaultVal;
+        Dialog_Utils::makeLabeledEditField(genLayout, row,
+                                           pTagLabel[i], adef.name,
+                                           pTagLineEdit[i], tagInitVal, 2 + (i * 2));
+    }
+}
+
+/**
+ * Update the stereotype tag values of the given UMLObject from the
+ * corresponding values in the given array of KLineEdit widgets.
+ * This is useful as the action in the slot method when the Apply or
+ * OK button is pressed.
+ */
+void updateTagsFromEditFields(UMLObject * o,
+                              KLineEdit *pTagLineEdit[N_STEREOATTRS])
+{
+    UMLStereotype *stereo = o->umlStereotype();
+    if (stereo == 0)
+        return;
+    const UMLStereotype::AttributeDefs& attrDefs = stereo->getAttributeDefs();
+    QStringList& tags = o->tags();
+    tags.clear();
+    for (int i = 0; i < attrDefs.size() && i < N_STEREOATTRS; i++) {
+        if (pTagLineEdit[i] == 0) {
+            uError() << "updateTagsFromEditFields(" << o->name() << "): " << stereo->name(true)
+                     << " pTagLineEdit[" << i << "] is null";
+            break;
+        }
+        QString tag = pTagLineEdit[i]->text();
+        tags.append(tag);
+    }
+}
+
 /**
  * Helper function for requesting a name for a UMLWidget using a dialog.
  *
